@@ -1,10 +1,9 @@
 # -*- perl -*-
 
 #
-# $Id: CanvasFig.pm,v 1.15 2003/10/22 21:34:25 eserte Exp $
 # Author: Slaven Rezic
 #
-# Copyright (C) 1998,2001,2002 Slaven Rezic. All rights reserved.
+# Copyright (C) 1998,2001,2002,2009 Slaven Rezic. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -23,7 +22,7 @@ use strict;
 use vars qw($VERSION %capstyle %joinstyle %figcolor @figcolor
 	    $usercolorindex);
 
-$VERSION = sprintf("%d.%03d", q$Revision: 1.15 $ =~ /(\d+)\.(\d+)/);
+$VERSION = 1.016;
 
 %capstyle = ('butt' => 0,
 	     'projecting' => 2,
@@ -681,7 +680,7 @@ because C<netpbm> programs does not handle transparency.
 
 =head1 SEE ALSO
 
-L<Tk|Tk>, L<Tk::Canvas|Tk::Canvas>, L<xfig|xfig>
+L<Tk>, L<Tk::Canvas>, L<xfig(1)>
 
 =head1 AUTHOR
 
@@ -689,7 +688,7 @@ Slaven Rezic <slaven@rezic.de>
 
 =head1 COPYRIGHT
 
-Copyright (c) 1998, 2001, 2002 Slaven Rezic. All rights reserved. This
+Copyright (c) 1998, 2001, 2002, 2009 Slaven Rezic. All rights reserved. This
 module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
